# Simple Enumerator for d-DNNF

We provide a simple enumerator for d-DNNFs generated by GPMC (experimentally). 
GPMC can output a d-DNNF file representing the set of models of a given CNF file, with "-ddnnf" and "-nnfout=\<filename\>" options.
The enumerator counts or enumerates the models in a very simple way for a given d-DNNF.
We do not deal with literal weights yet, so the tool deals with d-DDNFs generated by GPMC with mode 0(MC) and 2(PMC). 

## Usage
```
$ python3 main.py <d-DNNF file>
```

After you run the python script, it will read the input d-DNNF file. 
After that, you can run a few types of tasks by provinding commands. See help messages by "help" command.  